@@ -5,7 +5,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '0.20'; 
+$VERSION = '0.21'; 
 
 use Carp qw(carp croak);
 use Errno qw(ETIMEDOUT ECONNRESET);
@@ -48,10 +48,12 @@ POE::Component::Client::WebSocket - A POE compatible websocket client
 
 =head1 VERSION
 
-Version 0.01
+Version 0.21
 
 =head1 WARNING: Work in progress! Only uploaded early for testing purposes!
 
+This module appears to work perfectly, however its not really been tested that much and I will be amazed if there are not bugs.
+
 =head1 SYNOPSIS
 
     #!/usr/bin/env perl
@@ -104,7 +106,7 @@ Version 0.01
 
 =head2 new
 
-Create a new object
+Create a new object, takes 1 argument.. a fully qualified websocket URI.
 
 =cut
 
@@ -119,6 +121,7 @@ sub new {
         my ($scheme, $auth, $path, $query, $frag) = uri_split($uri);
         my ($host,$port) = split(/:/,$auth);
 
+        # If we are on WSS we are probably using https, if not probably http
         if (!$port) {
                 if (uc($scheme) eq 'WSS')       { $port = 443 }
                 else                            { $port = 80 }
@@ -138,6 +141,7 @@ sub new {
                                 handler         =>      '_handler',
                                 origin          =>      '_origin',
                                 send            =>      '_send',
+                                parent          =>      '_parent',
                                 socket_birth    =>      '_socket_birth',
                                 socket_death    =>      '_socket_death',
                                 socket_input    =>      '_socket_input',
@@ -178,8 +182,50 @@ sub new {
         return $self;    
 }
 
+=head1 Default handlers and arguments
+
+All of these can be changed with the 'handler' function, note the 'event key'.
+
+=head2 read (websocket_read)
+
+event key: read
+default handler: websocket_read
+
+Data that has been read and decoded from the server.
+
+
+=head2 disconnected (websocket_disconnected)
+
+event key: disconnected
+default handler: websocket_disconnected
+
+Called when the websocket is disconnected.
+
+=head2 connected (websocket_connected)
+
+event key: connected
+default handler: websocket_connected
+
+Called when the websocket is connected (before the handshake) ARG0 contains the HTTP::Request sent.
+
+=head2 handshake (websocket_handshake)
+
+event key: handshake
+default handler: websocket_handshake
+
+Called when the socket handshake is completed, ARG0 contains the HTTP::Response from the server.
+
+=head2 error (websocket_error)
+
+event key: error
+default handler: websocket_error
+
+Called when an error is retrieved, this is a bit vague at the moment ARG0 should contain something.
+
 =head1 OOP mappings from obj to POE
 
+These can be called with a standard POE style POST or directly from the object (see SYNOPSIS for examples of both)
+
 =head2 connect
 
 Start the connection
@@ -209,7 +255,7 @@ sub handler {
 
 =head2 origin
 
-Change the origin from the automatically generated one to something else
+Change the origin from the automatically generated one to something else.
 
 =cut
 
@@ -225,6 +271,24 @@ sub origin {
         );
 }
 
+=head2 parent
+
+Override the 'send to' parent for the module, by default this is the module that the component was started from.
+
+=cut
+
+sub parent {
+        my ($self,$target) = @_;
+
+        return if (!$target);
+
+        POE::Kernel->post(
+                $self->{session}->ID,
+                'parent',
+                $target
+        );
+}
+
 =head2 send
 
 Send data to the server, arguments are:
@@ -325,6 +389,17 @@ sub _origin {
         $heap->{req}->{origin} = $target;
 }
 
+=head2 _parent
+
+Change the currently targeted session to communicate events with.
+
+=cut
+
+sub _parent {
+        my ($kernel,$heap,$target) = @_[KERNEL,HEAP,ARG0];
+
+        $heap->{parent} = $target;
+}
 
 =head2 _send
 
